==> foundation-core-app-1.6.0.tgz: package/common/hero/variants/hero-banner/HeroBanner.styled.tsx <==
/* eslint-disable indent */
import { AllColorKeyType, ColorUtils, styled } from '@nuskin/foundation-theme';
import { NsLink } from '@nuskin/foundation-ui-components';

import { AlignmentType } from '../../types/types';
import { HeroContentContainer, HeroImageContainer, HeroTextContainer } from '../../helper-components/HeroCommon.styled';
import ABSOLUTE_FILL from '../../../theme/styles';
import { breakpoints } from '../../../theme';

const { getGenomeColor } = ColorUtils;
/**
 * Renders a tint over the image when a parent container has .with-scrim class
 */
export const ImageContainer = styled(HeroImageContainer)`
    position: relative;
    width: 100%;
    img {
        width: auto;
        float: left;
    }
    ::after {
        content: ' ';
        display: block;
        clear: both;
    }

    .with-scrim &::before {
        ${ABSOLUTE_FILL}
        content: " ";
        display: block;
        z-index: 1;
        background-color: #00000040;
    }

    .text-align-start & img {
        float: right;
        margin-right: -90px;
        ::after {
            clear: both;
        }
    }

    .text-align-end & img {
        float: left;
        ::after {
            clear: both;
        }
    }

    .text-align-start &,
    .text-align-center &,
    .text-align-end & {
        ${breakpoints.sm} {
            img {
                float: none;
                margin: 0;
                object-fit: cover;
                object-position: center;
                width: 100%;
                height: 100%;
            }
        }
    }

    ${breakpoints.sm} {
        ${ABSOLUTE_FILL}
        video {
            min-width: 100%;
            min-height: 100%;
            width: auto;
            height: auto;
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
        }
    }
`;

export const TextContainer = styled(HeroTextContainer)`
    padding: 30px;
    z-index: 2;

    button {
        margin-top: 30px;
    }

    ${breakpoints.sm} {
        position: relative;
        z-index: 1;
        width: 50%;
        padding: 0;
    }

    ${breakpoints.lg} {
        width: 45%;
    }
`;

export const ContentContainer = styled(HeroContentContainer)<{
    textAlignment: AlignmentType;
    backgroundColor: AllColorKeyType;
}>`
    align-items: center;
    justify-content: ${({ textAlignment }) => textAlignment} !important;
    text-align: center !important;
    background-color: ${({ theme, backgroundColor }) => getGenomeColor(theme, backgroundColor)};
    .hero-text-container {
        width: 80%;
        max-width: 800px;
    }
    ${breakpoints.sm} {
        flex-direction: row;
        position: relative;
        min-height: 400px;
        padding: 30px 40px;
        text-align: center;
    }
    ${breakpoints.md} {
        text-align: ${({ textAlignment }) =>
            textAlignment === 'center' ? 'center' : 'left'} !important;
    }

    ${breakpoints.lg} {
        padding: 60px 200px;
        min-height: 400px;
    }
`;

export const StyledLink = styled(NsLink)`
    display: block;
    height: 100%;
    width: 100%;
    position: relative;
    text-decoration: none;
`;

==> foundation-core-app-1.10.2.tgz: package/common/hero/variants/hero-banner/HeroBanner.styled.tsx <==
/* eslint-disable indent */
import { AllColorKeyType, ColorUtils, styled } from '@nuskin/foundation-theme';
import { NsLink } from '@nuskin/foundation-ui-components';

import { AlignmentType } from '../../types/types';
import { HeroContentContainer, HeroImageContainer, HeroTextContainer } from '../../helper-components/HeroCommon.styled';
import ABSOLUTE_FILL from '../../../theme/styles';
import { breakpoints } from '../../../theme';

const { getGenomeColor } = ColorUtils;
/**
 * Renders a tint over the image when a parent container has .with-scrim class
 */
export const ImageContainer = styled(HeroImageContainer)`
    position: relative;
    width: 100%;
    img {
        width: auto;
        float: left;
    }
    ::after {
        content: ' ';
        display: block;
        clear: both;
    }

    .with-scrim &::before {
        ${ABSOLUTE_FILL}
        content: " ";
        display: block;
        z-index: 1;
        background-color: #00000040;
    }

    .text-align-start & img {
        float: right;
        margin-right: -90px;
        ::after {
            clear: both;
        }
    }

    .text-align-end & img {
        float: left;
        ::after {
            clear: both;
        }
    }

    .text-align-start &,
    .text-align-center &,
    .text-align-end & {
        ${breakpoints.sm} {
            img {
                float: none;
                margin: 0;
                object-fit: cover;
                object-position: center;
                width: 100%;
                height: 100%;
            }
        }
    }

    ${breakpoints.sm} {
        ${ABSOLUTE_FILL}
        video {
            min-width: 100%;
            min-height: 100%;
            width: auto;
            height: auto;
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
        }
    }
`;

export const TextContainer = styled(HeroTextContainer)`
    padding: 30px;
    z-index: 2;

    button {
        margin-top: 30px;
    }

    ${breakpoints.sm} {
        position: relative;
        z-index: 1;
        width: 50%;
        padding: 0;
    }

    ${breakpoints.lg} {
        width: 45%;
    }
`;

export const ContentContainer = styled(HeroContentContainer)<{
    textAlignment: AlignmentType;
    backgroundColor: AllColorKeyType;
}>`
    align-items: center;
    justify-content: ${({ textAlignment }) => textAlignment} !important;
    text-align: center !important;
    background-color: ${({ theme, backgroundColor }) => getGenomeColor(theme, backgroundColor)};
    .hero-text-container {
        width: ${({ textAlignment }) => (textAlignment === 'center' ? '540px' : '450px')};
        max-width: 800px;
        button {
            height: 44px;
        }
    }
    ${breakpoints.sm} {
        flex-direction: row;
        position: relative;
        min-height: 400px;
        padding: 30px 40px;
        text-align: center;
        .hero-text-container {
            width: 300px;
        }
    }
    ${breakpoints.md} {
        text-align: ${({ textAlignment }) => (textAlignment === 'center' ? 'center' : 'left')} !important;
    }

    ${breakpoints.lg} {
        padding: 60px 200px;
        min-height: 400px;
    }
`;
